@@ -5,8 +5,7 @@ from pathlib import Path
 import pickle
 import sys
 from tempfile import TemporaryDirectory
-from typing import Any, Iterable, List, Optional, Set, Tuple, Union
-from typing_extensions import Literal
+from typing import Any, Iterable, List, Literal, Optional, Set, Tuple, Union
 import unittest
 from unittest import TestCase
 
@@ -1602,5 +1601,34 @@ class TestParserDescription(TestCase):
         self.assertNotIn("I do not exist", help_desc)
 
 
+class TestDefaultImmutability(TestCase):
+    def test_default_immutability(self):
+        holy_hand_grenada = [1, 2, 5]  # no, 3 sir!
+
+        class DefaultImmutabilityTap(Tap):
+            array: List[int] = holy_hand_grenada
+
+        args = DefaultImmutabilityTap().parse_args([])
+        self.assertEqual(args.array, holy_hand_grenada)
+
+        holy_hand_grenada[2] = 3
+        self.assertEqual(args.array, [1, 2, 5])
+
+    def test_default_immutability_configure(self):
+        holy_hand_grenada = [1, 2, 5]
+
+        class DefaultImmutabilityTap(Tap):
+            array: List[int]
+
+            def configure(self) -> None:
+                self.add_argument('--array', default=holy_hand_grenada)
+
+        args = DefaultImmutabilityTap().parse_args([])
+        self.assertEqual(args.array, holy_hand_grenada)
+
+        holy_hand_grenada[2] = 3
+        self.assertEqual(args.array, [1, 2, 5])
+
+
 if __name__ == '__main__':
     unittest.main()
